/*
 *   Copyright 2010 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */
package net.brutex.xservices.types;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;

/**
 * MIME types for email messages.
 * This type restricts the mime types to be used within the
 * email body.
 *
 * @author Brian Rosenberger, bru@brutex.de
 * @since 0.4.0
 */
@XmlEnum(value = String.class)
public enum MailMimeType {

    /**
     * Plain text.
     */
    @XmlEnumValue("text/plain")
    PLAIN("text/plain"),
    /**
     * HTML
     */
    @XmlEnumValue("text/html")
    HTML("text/html");
    private String value;

    MailMimeType(String value) {
        this.value = value;
    }

    /**
     * Return the value of the enum.
     * @return  String representation of the mime type
     */
    public String value() {
        return value;
    }
}
