/*
 *   Copyright 2011 Brian Rosenberger (Brutex Network)
 *
 *   Licensed under the Apache License, Version 2.0 (the "License");
 *   you may not use this file except in compliance with the License.
 *   You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *   Unless required by applicable law or agreed to in writing, software
 *   distributed under the License is distributed on an "AS IS" BASIS,
 *   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *   See the License for the specific language governing permissions and
 *   limitations under the License.
 */

package net.brutex.xservices.ws;

import javax.jws.WebMethod;
import javax.jws.WebParam;
import javax.jws.WebService;
import javax.xml.bind.annotation.XmlElement;

import net.brutex.xservices.types.HostConnection;
import net.brutex.xservices.types.ReturnCode;
import net.brutex.xservices.util.BrutexNamespaces;

/**
 * Task execution web service
 * 
 * @author Brian Rosenberger
 * @since 0.1.0
 *
 */
@WebService(targetNamespace = BrutexNamespaces.WS_XSERVICES)
public interface ExecuteService {

	/**
	 * @param cmd
	 * @param args
	 * @param timeout
	 * @return
	 */
	@WebMethod(operationName = "runCommand")
	public abstract ReturnCode runCommand(
			@WebParam(name = "executable") String cmd,
			@WebParam(name = "argline") String args,
			@WebParam(name = "timeout") long timeout);

	/**
	 * @param cmd
	 * @param args
	 * @param timeout
	 * @return
	 */
	@WebMethod(operationName = "runCommandWithArgs")
	public abstract ReturnCode runCommandWithArgs(
			@WebParam(name = "executable") String cmd,
			@WebParam(name = "arg") String[] args,
			@WebParam(name = "timeout") long timeout);

	/**
	 * @param cmd
	 * @param args
	 * @return
	 */
	@WebMethod(operationName = "runCommandAsync")
	public abstract ReturnCode runCommandAsync(
			@WebParam(name = "executable") String cmd,
			@WebParam(name = "argline") String args);

	/**
	 * @param cmd
	 * @param args
	 * @return
	 */
	@WebMethod(operationName = "runCommandAsyncWithArgs")
	public abstract ReturnCode runCommandAsyncWithArgs(
			@WebParam(name = "executable") String cmd,
			@WebParam(name = "arg") String[] args);

	/**
	 * @param host
	 * @param cmd
	 * @param timeout
	 * @return
	 */
	@WebMethod(operationName = "runCommandWithSSH")
	public abstract ReturnCode runCommandWithSSH(
			@WebParam(name = "host") HostConnection host,
			@WebParam(name = "command") String cmd,
			@WebParam(name = "timeout") long timeout);

	/**
	 * @param host
	 * @param keyfile
	 * @param cmd
	 * @param timeout
	 * @return
	 */
	@WebMethod(operationName = "runCommandWithSSHKeyAuth")
	public abstract ReturnCode runCommandWithSSHKeyAuth(
			@WebParam(name = "host") HostConnection host,
			@WebParam(name = "keyfile") String keyfile,
			@WebParam(name = "command") String cmd,
			@WebParam(name = "timeout") long timeout);

	/**
	 * @param host
	 * @param cmd
	 * @param timeout
	 * @return
	 */
	@WebMethod(operationName = "rExec")
	public abstract ReturnCode rExec(
			@WebParam(name = "host") HostConnection host,
			@WebParam(name = "command") String cmd,
			@WebParam(name = "timeout") long timeout);

	/**
	 * @param host
	 * @param prompt
	 * @param cmd
	 * @param expect
	 * @param timeout
	 * @return
	 */
	@WebMethod(operationName = "telnet")
	public abstract ReturnCode runTelnet(
			@WebParam(name = "host") HostConnection host,
			@WebParam(name = "prompt") String prompt,
			@WebParam(name = "command") String cmd,
			@WebParam(name = "expect") String expect,
			@WebParam(name = "timeout") long timeout);
	
	/**
	 * @param script
	 * @throws XServicesFault
	 */
	@WebMethod(operationName = "runJavaScript")
	public abstract void runJScript(
			@WebParam(name = "script") @XmlElement(required=true) String script) throws XServicesFault;
	

}